VirtioInputDevice

Struct VirtioInputDevice 

pub struct VirtioInputDevice {
    base_addr: usize,
    eventq: Mutex<VirtQueue<'static>>,
    statusq: Mutex<VirtQueue<'static>>,
    event_device: Arc<EventDevice>,
    initialized: Mutex<bool>,
    event_buffers: Mutex<Vec<Box<[u8]>>>,
    interrupt_id: Mutex<Option<u32>>,
}
VirtIO Input Device

Fields

base_addr: usizeeventq: Mutex<VirtQueue<'static>>statusq: Mutex<VirtQueue<'static>>event_device: Arc<EventDevice>initialized: Mutex<bool>event_buffers: Mutex<Vec<Box<[u8]>>>interrupt_id: Mutex<Option<u32>>

Implementations

Source

impl VirtioInputDevice

fn read8_config(&self, offset: usize) -> u8

Read a u8 from configuration space

fn write8_config(&self, offset: usize, value: u8)

Write a u8 to configuration space

fn read_device_name(&self) -> Option<String>

Read device name from configuration

fn determine_device_type(name: &str) -> &'static str

Determine device type from name

pub fn new(base_addr: usize) -> Self

Create a new VirtIO Input device

Arguments
  • base_addr - The base address of the device
Returns

A new instance of VirtioInputDevice

fn init(&mut self) -> Result<(), &'static str>

Initialize the VirtIO input device

fn setup_queues(&mut self) -> Result<(), &'static str>

Setup virtqueues

fn prefill_event_queue(&mut self) -> Result<(), &'static str>

Prefill event queue with receive buffers

pub fn handle_interrupt(&self)

Handle input events from the device

This should be called from the interrupt handler or periodically polled

pub fn poll_events(&self)

Poll for events (for testing without interrupt support)

This can be called periodically to check for events when interrupt handling is not yet implemented

fn process_events(&self)

Process events from the event queue

pub fn enable_interrupts(&self, interrupt_id: u32) -> Result<(), &'static str>

Enable interrupts for this device

pub fn get_event_device(&self) -> Arc<EventDevice>

Get the EventDevice for this input device