pub struct VirtioInputDevice {
base_addr: usize,
eventq: Mutex<VirtQueue<'static>>,
statusq: Mutex<VirtQueue<'static>>,
event_device: Arc<EventDevice>,
initialized: Mutex<bool>,
event_buffers: Mutex<Vec<Box<[u8]>>>,
interrupt_id: Mutex<Option<u32>>,
}Expand description
VirtIO Input Device
Fields
base_addr: usizeeventq: Mutex<VirtQueue<'static>>statusq: Mutex<VirtQueue<'static>>event_device: Arc<EventDevice>initialized: Mutex<bool>event_buffers: Mutex<Vec<Box<[u8]>>>interrupt_id: Mutex<Option<u32>>Implementations
Sourceimpl VirtioInputDevice
impl VirtioInputDevice
Sourcefn read8_config(&self, offset: usize) -> u8
fn read8_config(&self, offset: usize) -> u8
Read a u8 from configuration space
Sourcefn write8_config(&self, offset: usize, value: u8)
fn write8_config(&self, offset: usize, value: u8)
Write a u8 to configuration space
Sourcefn read_device_name(&self) -> Option<String>
fn read_device_name(&self) -> Option<String>
Read device name from configuration
Sourcefn determine_device_type(name: &str) -> &'static str
fn determine_device_type(name: &str) -> &'static str
Determine device type from name
Sourcefn setup_queues(&mut self) -> Result<(), &'static str>
fn setup_queues(&mut self) -> Result<(), &'static str>
Setup virtqueues
Sourcefn prefill_event_queue(&mut self) -> Result<(), &'static str>
fn prefill_event_queue(&mut self) -> Result<(), &'static str>
Prefill event queue with receive buffers
Sourcepub fn handle_interrupt(&self)
pub fn handle_interrupt(&self)
Handle input events from the device
This should be called from the interrupt handler or periodically polled
Sourcepub fn poll_events(&self)
pub fn poll_events(&self)
Poll for events (for testing without interrupt support)
This can be called periodically to check for events when interrupt handling is not yet implemented
Sourcefn process_events(&self)
fn process_events(&self)
Process events from the event queue
Sourcepub fn enable_interrupts(&self, interrupt_id: u32) -> Result<(), &'static str>
pub fn enable_interrupts(&self, interrupt_id: u32) -> Result<(), &'static str>
Enable interrupts for this device
Sourcepub fn get_event_device(&self) -> Arc<EventDevice>
pub fn get_event_device(&self) -> Arc<EventDevice>
Get the EventDevice for this input device